@@ -90,9 +90,9 @@ impl PartialEq for Cell {
 /// A Cell is guaranteed to contain a Source Chain which has undergone
 /// Genesis.
 ///
-/// The [Conductor] manages a collection of Cells, and will call functions
+/// The [`Conductor`](super::Conductor) manages a collection of Cells, and will call functions
 /// on the Cell when a Conductor API method is called (either a
-/// [CellConductorApi] or an [AppInterfaceApi])
+/// [`CellConductorApi`](super::api::CellConductorApi) or an [`AppInterfaceApi`](super::api::AppInterfaceApi))
 pub struct Cell<Api = CellConductorApi, P2pCell = holochain_p2p::HolochainP2pDna>
 where
     Api: CellConductorApiT,
@@ -934,6 +934,11 @@ impl Cell {
         }
     }
 
+    /// Accessor for the p2p_agents_db backing this Cell
+    pub(crate) fn p2p_agents_db(&self) -> &DbWrite<DbKindP2pAgents> {
+        &self.space.p2p_agents_db
+    }
+
     /// Accessor for the authored database backing this Cell
     pub(crate) fn authored_db(&self) -> &DbWrite<DbKindAuthored> {
         &self.space.authored_db
