@@ -115,7 +115,7 @@ mod tests {
     use super::EntryDefBufferKey;
     use crate::conductor::Conductor;
     use holo_hash::HasHash;
-    use holochain_state::prelude::test_environments;
+    use holochain_state::prelude::test_db_dir;
     use holochain_types::prelude::*;
     use holochain_types::test_utils::fake_dna_zomes;
     use holochain_wasm_test_utils::TestWasm;
@@ -125,8 +125,8 @@ mod tests {
         observability::test_run().ok();
 
         // all the stuff needed to have a WasmBuf
-        let envs = test_environments();
-        let handle = Conductor::builder().test(&envs, &[]).await.unwrap();
+        let db_dir = test_db_dir();
+        let handle = Conductor::builder().test(db_dir.path(), &[]).await.unwrap();
 
         let dna = fake_dna_zomes(
             "",
@@ -172,7 +172,7 @@ mod tests {
         std::mem::drop(handle);
 
         // Restart conductor and check defs are still here
-        let handle = Conductor::builder().test(&envs.into(), &[]).await.unwrap();
+        let handle = Conductor::builder().test(db_dir.path(), &[]).await.unwrap();
 
         assert_eq!(handle.get_entry_def(&post_def_key), Some(post_def));
         assert_eq!(
