@@ -4,17 +4,19 @@
 use super::{SweetAgents, SweetApp, SweetAppBatch, SweetCell, SweetConductorHandle};
 use crate::conductor::{
     api::error::ConductorApiResult, config::ConductorConfig, error::ConductorResult,
-    handle::ConductorHandle, CellError, Conductor, ConductorBuilder,
+    handle::ConductorHandle, space::Spaces, CellError, Conductor, ConductorBuilder,
 };
 use hdk::prelude::*;
 use holo_hash::DnaHash;
 use holochain_conductor_api::{AdminInterfaceConfig, InterfaceDriver};
 use holochain_keystore::MetaLairClient;
-use holochain_state::test_utils::{test_environments, TestEnvs};
+use holochain_state::prelude::test_db_dir;
 use holochain_types::prelude::*;
 use holochain_websocket::*;
 use kitsune_p2p::KitsuneP2pConfig;
+use std::path::Path;
 use std::sync::Arc;
+use tempfile::TempDir;
 
 /// A stream of signals.
 pub type SignalStream = Box<dyn tokio_stream::Stream<Item = Signal> + Send + Sync + Unpin>;
@@ -28,7 +30,9 @@ pub type SignalStream = Box<dyn tokio_stream::Stream<Item = Signal> + Send + Syn
 #[derive(derive_more::From)]
 pub struct SweetConductor {
     handle: Option<SweetConductorHandle>,
-    envs: TestEnvs,
+    db_dir: TempDir,
+    keystore: MetaLairClient,
+    pub(crate) spaces: Spaces,
     config: ConductorConfig,
     dnas: Vec<DnaFile>,
     signal_stream: Option<SignalStream>,
@@ -36,7 +40,13 @@ pub struct SweetConductor {
 
 /// Standard config for SweetConductors
 pub fn standard_config() -> ConductorConfig {
+    let mut tuning_params =
+        kitsune_p2p_types::config::tuning_params_struct::KitsuneP2pTuningParams::default();
+    // note, even with this tuning param, the `SSLKEYLOGFILE` env var
+    // still must be set in order to enable session keylogging
+    tuning_params.danger_tls_keylog = "env_keylog".to_string();
     let mut network = KitsuneP2pConfig::default();
+    network.tuning_params = Arc::new(tuning_params);
     network.transport_pool = vec![kitsune_p2p::TransportConfig::Quic {
         bind_to: None,
         override_host: None,
@@ -59,7 +69,7 @@ impl SweetConductor {
     /// "sweet-interface" so that signals may be emitted
     pub async fn new(
         handle: ConductorHandle,
-        envs: TestEnvs,
+        env_dir: TempDir,
         config: ConductorConfig,
     ) -> SweetConductor {
         // Automatically add a test app interface
@@ -71,9 +81,21 @@ impl SweetConductor {
         // Get a stream of all signals since conductor startup
         let signal_stream = handle.signal_broadcaster().await.subscribe_merged();
 
+        // XXX: this is a bit wonky.
+        // We create a Spaces instance here purely because it's easier to initialize
+        // the per-space databases this way. However, we actually use the TestEnvs
+        // to actually access those databases.
+        // As a TODO, we can remove the need for TestEnvs in sweettest or have
+        // some other better integration between the two.
+        let spaces = Spaces::new(env_dir.path().to_path_buf().into(), Default::default()).unwrap();
+
+        let keystore = handle.keystore().clone();
+
         Self {
             handle: Some(SweetConductorHandle(handle)),
-            envs,
+            db_dir: env_dir,
+            keystore,
+            spaces,
             config,
             dnas: Vec::new(),
             signal_stream: Some(Box::new(signal_stream)),
@@ -82,30 +104,30 @@ impl SweetConductor {
 
     /// Create a SweetConductor with a new set of TestEnvs from the given config
     pub async fn from_config(config: ConductorConfig) -> SweetConductor {
-        let envs = test_environments();
-        let handle = Self::handle_from_existing(&envs, &config, &[]).await;
-        Self::new(handle, envs, config).await
+        let dir = test_db_dir();
+        let handle = Self::handle_from_existing(dir.path(), test_keystore(), &config, &[]).await;
+        Self::new(handle, dir, config).await
     }
 
     /// Create a SweetConductor from a partially-configured ConductorBuilder
-    pub async fn from_builder<DS: DnaStore + 'static>(
-        builder: ConductorBuilder<DS>,
-    ) -> SweetConductor {
-        let envs = test_environments();
+    pub async fn from_builder(builder: ConductorBuilder) -> SweetConductor {
+        let db_dir = test_db_dir();
         let config = builder.config.clone();
-        let handle = builder.test(&envs, &[]).await.unwrap();
-        Self::new(handle, envs, config).await
+        let handle = builder.test(db_dir.path(), &[]).await.unwrap();
+        Self::new(handle, db_dir, config).await
     }
 
     /// Create a handle from an existing environment and config
     pub async fn handle_from_existing(
-        envs: &TestEnvs,
+        db_dir: &Path,
+        keystore: MetaLairClient,
         config: &ConductorConfig,
         extra_dnas: &[DnaFile],
     ) -> ConductorHandle {
         Conductor::builder()
             .config(config.clone())
-            .test(envs, extra_dnas)
+            .with_keystore(keystore)
+            .test(db_dir, extra_dnas)
             .await
             .unwrap()
     }
@@ -115,14 +137,14 @@ impl SweetConductor {
         Self::from_config(standard_config()).await
     }
 
-    /// Access the TestEnvs for this conductor
-    pub fn envs(&self) -> &TestEnvs {
-        &self.envs
+    /// Access the database path for this conductor
+    pub fn db_path(&self) -> &Path {
+        self.db_dir.path()
     }
 
     /// Access the MetaLairClient for this conductor
     pub fn keystore(&self) -> MetaLairClient {
-        self.envs.keystore().clone()
+        self.keystore.clone()
     }
 
     /// Convenience function that uses the internal handle to enable an app
@@ -209,13 +231,17 @@ impl SweetConductor {
     ) -> ConductorApiResult<SweetApp> {
         let mut sweet_cells = Vec::new();
         for dna_hash in dna_hashes {
-            let cell_authored_env = self.handle().0.get_authored_env(&dna_hash)?;
-            let cell_dht_env = self.handle().0.get_dht_env(&dna_hash)?;
+            // Initialize per-space databases
+            let _space = self.spaces.get_or_create_space(&dna_hash)?;
+
+            // Create the SweetCell
+            let cell_authored_db = self.handle().0.get_authored_db(&dna_hash)?;
+            let cell_dht_db = self.handle().0.get_dht_db(&dna_hash)?;
             let cell_id = CellId::new(dna_hash, agent.clone());
             let cell = SweetCell {
                 cell_id,
-                cell_authored_env,
-                cell_dht_env,
+                cell_authored_db,
+                cell_dht_db,
             };
             sweet_cells.push(cell);
         }
@@ -358,7 +384,13 @@ impl SweetConductor {
     pub async fn startup(&mut self) {
         if self.handle.is_none() {
             self.handle = Some(SweetConductorHandle(
-                Self::handle_from_existing(&self.envs, &self.config, self.dnas.as_slice()).await,
+                Self::handle_from_existing(
+                    self.db_dir.path(),
+                    self.keystore.clone(),
+                    &self.config,
+                    self.dnas.as_slice(),
+                )
+                .await,
             ));
         } else {
             panic!("Attempted to start conductor which was already started");
@@ -395,17 +427,17 @@ impl SweetConductor {
         if let Some(handle) = self.handle.as_ref() {
             let iter = handle.list_cell_ids(None).into_iter().map(|id| async {
                 let id = id;
-                let env = self.get_authored_env(id.dna_hash()).unwrap();
+                let db = self.get_authored_db(id.dna_hash()).unwrap();
                 let trigger = self.get_cell_triggers(&id).unwrap();
-                (env, trigger)
+                (db, trigger)
             });
             futures::stream::iter(iter)
                 .then(|f| f)
-                .for_each(|(env, mut triggers)| async move {
+                .for_each(|(db, mut triggers)| async move {
                     // The line below was added when migrating to rust edition 2021, per
                     // https://doc.rust-lang.org/edition-guide/rust-2021/disjoint-capture-in-closures.html#migration
                     let _ = &triggers;
-                    crate::test_utils::force_publish_dht_ops(&env, &mut triggers.publish_dht_ops)
+                    crate::test_utils::force_publish_dht_ops(&db, &mut triggers.publish_dht_ops)
                         .await
                         .unwrap();
                 })
