@@ -1,4 +1,5 @@
 use super::SweetZome;
+use crate::conductor::api::error::ConductorApiError;
 use crate::conductor::{api::error::ConductorApiResult, ConductorHandle};
 use holochain_conductor_api::ZomeCall;
 use holochain_types::prelude::*;
@@ -84,11 +85,13 @@ impl SweetConductorHandle {
             provenance: provenance.clone(),
             payload,
         };
-        self.handle().call_zome(call).await.map(|r| {
-            unwrap_to!(r.unwrap() => ZomeCallResponse::Ok)
+        match self.handle().call_zome(call).await {
+            Ok(Ok(response)) => Ok(unwrap_to!(response => ZomeCallResponse::Ok)
                 .decode()
-                .expect("Couldn't deserialize zome call output")
-        })
+                .expect("Couldn't deserialize zome call output")),
+            Ok(Err(error)) => Err(ConductorApiError::Other(Box::new(error))),
+            Err(error) => Err(error),
+        }
     }
 
     // /// Get a stream of all Signals emitted since the time of this function call.
