@@ -254,7 +254,7 @@ where
     let mut key_fixt = AgentPubKeyFixturator::new(Predictable);
     let agent_key = agent_key.unwrap_or_else(|| key_fixt.next().unwrap());
     let dna_network = network.to_dna(dna.clone());
-    network.join(dna.clone(), agent_key).await.unwrap();
+    network.join(dna.clone(), agent_key, None).await.unwrap();
     TestNetwork::new(network, respond_task, dna_network)
 }
 
