@@ -400,8 +400,8 @@ async fn create_test_data(
     let mut ops = HashMap::new();
     for (i, cell) in cells.iter().enumerate() {
         eprintln!("Extracting data {}", i);
-        let env = cell.authored_env().clone();
-        let data = fresh_reader_test(env, |mut txn| {
+        let db = cell.authored_db().clone();
+        let data = fresh_reader_test(db, |mut txn| {
             get_authored_ops(&mut txn, cell.agent_pubkey())
         });
         let hashes = data.keys().cloned().collect::<Vec<_>>();
